__version__ = '0.3.1'

from skglm.estimators import (  # noqa F401
    Lasso, WeightedLasso, ElasticNet, MCPRegression, MultiTaskLasso, LinearSVC,
    SparseLogisticRegression, GeneralizedLinearEstimator, CoxEstimator
)
